@@ -1,20 +1,21 @@
 /*
  * file.cc: Part of GNU CSSC.
  *
- *    Copyright (C) 1997,1998,1999,2001,2007,2008 Free Software Foundation, Inc.
+ *  Copyright (C) 1997, 1998, 1999, 2001, 2007, 2008, 2009, 2010, 2011,
+ *  2014, 2019 Free Software Foundation, Inc.
  *
- *    This program is free software: you can redistribute it and/or modify
- *    it under the terms of the GNU General Public License as published by
- *    the Free Software Foundation, either version 3 of the License, or
- *    (at your option) any later version.
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- *    This program is distributed in the hope that it will be useful,
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *    You should have received a copy of the GNU General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  * CSSC was originally Based on MySC, by Ross Ridge, which was
  * placed in the Public Domain.
@@ -23,19 +24,23 @@
  * System dependent routines for accessing files.
  *
  */
-#include <errno.h>
+#include "config.h"
 
-#include "cssc.h"
+#include <string>
+#include <errno.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+#include <stdio.h>
+#include <stdlib.h>
+
+#include "cssc.h"		/* for CONFIG_CAN_HARD_LINK_AN_OPEN_FILE */
 #include "cssc-assert.h"
 #include "sysdep.h"
 #include "file.h"
 #include "quit.h"
 #include "ioerr.h"
 #include "defaults.h"
-
-#include <unistd.h>
-#include <sys/stat.h>
-#include <stdio.h>
 #include "dirent-safer.h"
 
 /* Redirects stdout to a "null" file (eg. /dev/null). */
@@ -111,6 +116,35 @@ is_readable(const char *name) {
         return access(name, 04) != -1;
 }
 
+static bool
+get_mode_bits(const char *filename, mode_t mask, mode_t *result)
+{
+  struct stat st;
+  if (0 != stat(filename, &st))
+    return false;
+
+  *result = (st.st_mode & mask);
+  return true;
+}
+
+bool
+get_open_file_xbits (FILE *f, bool *is_executable)
+{
+  const int fd = fileno(f);
+  if (fd < 0)
+    return false;
+
+  struct stat st;
+  if (0 != fstat(fd, &st))
+    return false;
+
+  *is_executable = st.st_mode & 0111;
+  return true;
+}
+
+
+
+
 /* Determine if a given file is "writable".  If we
  * are root, we can write to a mode 000 file, but
  * we deem files of that sort not writable for these
@@ -126,22 +160,12 @@ is_readable(const char *name) {
 static int
 is_writable(const char *filename, int /* as_real_user = 1 */ )
 {
-  struct stat st;
-  if (0 != stat(filename, &st))
-    {
-      return 0;                 // can't stat it so can't read it, probably.
-    }
-  else
-    {
-      if (st.st_mode & 0222)
-        return 1;               // at least one of the write bits is set.
-      else
-        return 0;               // no write bits set.
-    }
-
+  mode_t bits;
+  if (!get_mode_bits(filename, 0222, &bits))
+    return 0;			// cannot tell
+  return bits ? 1 : 0;
 }
 
-
 /* Returns true if the file exists. */
 
 int
@@ -152,14 +176,14 @@ file_exists(const char *name) {
 
 
 
+static int unprivileged = 0;
+
 #ifdef CONFIG_UIDS
 
 /* A flag to indicate whether or not the programme is an privileged
    (effective UID != real UID) or unprivileged (effective UID == real
    UID). */
 
-static int unprivileged = 0;
-
 #ifdef SAVED_IDS_OK
 
 static uid_t old_euid;
@@ -308,15 +332,15 @@ restore_privileges()
 /* From the Linux manual page for open(2):-
  *
  * O_EXCL When used with O_CREAT, if the file already exists it is an
- *        error and the open will fail.  O_EXCL is broken on NFS file
- *        systems, programs which rely on it for performing locking
- *        tasks will contain a race condition.  The solution for
- *        performing atomic file locking using a lockfile is to create
- *        a unique file on the same fs (e.g., incorporating hostname
- *        and pid), use link(2) to make a link to the lockfile and use
- *        stat(2) on the unique file to check if its link count has
- *        increased to 2.  Do not use the return value of the link()
- *        call.
+ *      error and the open will fail.  O_EXCL is broken on NFS file
+ *      systems, programs which rely on it for performing locking
+ *      tasks will contain a race condition.  The solution for
+ *      performing atomic file locking using a lockfile is to create
+ *      a unique file on the same fs (e.g., incorporating hostname
+ *      and pid), use link(2) to make a link to the lockfile and use
+ *      stat(2) on the unique file to check if its link count has
+ *      increased to 2.  Do not use the return value of the link()
+ *      call.
  */
 
 
@@ -381,9 +405,9 @@ maybe_wait_a_bit(long attempt, const char *lockfile)
 }
 
 
-static int atomic_nfs_create(const mystring& path, int flags, int perms)
+static int atomic_nfs_create(const std::string& path, int flags, int perms)
 {
-  mystring dirname, basename;
+  std::string dirname, basename;
   char buf[32];
   const char *pstr = path.c_str();
 
@@ -394,7 +418,7 @@ static int atomic_nfs_create(const mystring& path, int flags, int perms)
     {
       /* form the name of a lock file. */
       sprintf(buf, "nfslck%ld", attempt);
-      const mystring lockname = dirname + mystring(buf);
+      const std::string lockname = dirname + std::string(buf);
       const char *lockstr = lockname.c_str();
 
       errno = 0;
@@ -471,7 +495,7 @@ static int atomic_nfs_create(const mystring& path, int flags, int perms)
 /* CYGWIN seems to be unable to create a file for writing, with mode
  * 0444, so this code resets the mode after we have closed the g-file.
  */
-bool set_file_mode(const mystring &gname, bool writable, bool executable)
+bool set_file_mode(const std::string &gname, bool writable, bool executable)
 {
   const char *name = gname.c_str();
   struct stat statbuf;
@@ -526,7 +550,7 @@ bool set_file_mode(const mystring &gname, bool writable, bool executable)
  * the real user's files.  However, we need to do this (for example,
  * for get -k).  This is SourceForge bug 451519.
  */
-bool set_gfile_writable(const mystring& gname, bool writable, bool executable)
+bool set_gfile_writable(const std::string& gname, bool writable, bool executable)
 {
   give_up_privileges();
   bool rv = set_file_mode(gname, writable, executable);
@@ -585,7 +609,7 @@ bool unlink_file_as_real_user(const char *gfile_name)
 /* returns a file descriptor open to a newly created file. */
 
 static int
-create(mystring name, int mode) {
+create(const std::string& name, int mode) {
         int flags = O_CREAT;
 
         if (mode & CREATE_FOR_UPDATE) {
@@ -621,7 +645,6 @@ create(mystring name, int mode) {
 
 	if (mode & CREATE_EXECUTABLE)
 	  {
-	    // A SCO extension.
 	    perms |= 0111;
 	  }
 
@@ -648,7 +671,7 @@ create(mystring name, int mode) {
 /* Returns a file stream open to a newly created file. */
 
 FILE *
-fcreate(mystring name, int mode) {
+fcreate(const std::string& name, int mode) {
         int fd = create(name.c_str(), mode);
         if (fd == -1) {
                 return NULL;
@@ -686,7 +709,7 @@ do_lock(FILE *f)                // process-aware version
 }
 
 
-file_lock::file_lock(mystring zname): locked(0), name(zname)
+file_lock::file_lock(const std::string& zname): locked(0), name(zname)
 {
   ASSERT(name == zname);
   FILE *f = fcreate(zname,
