@@ -2,20 +2,21 @@
  * file.h: Part of GNU CSSC.
  *
  *
- *    Copyright (C) 1997,2001,2007,2008 Free Software Foundation, Inc.
+ *  Copyright (C) 1997, 2001, 2007, 2008, 2009, 2010, 2011, 2014, 2019
+ *  Free Software Foundation, Inc.
  *
- *    This program is free software: you can redistribute it and/or modify
- *    it under the terms of the GNU General Public License as published by
- *    the Free Software Foundation, either version 3 of the License, or
- *    (at your option) any later version.
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- *    This program is distributed in the hope that it will be useful,
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *    You should have received a copy of the GNU General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  * CSSC was originally Based on MySC, by Ross Ridge, which was
  * placed in the Public Domain.
@@ -30,6 +31,9 @@
 #ifndef CSSC__FILE_H__
 #define CSSC__FILE_H__
 
+#include <string>
+using std::string;
+
 #include <sys/types.h>
 
 #include "filelock.h"
@@ -52,17 +56,18 @@ FILE *open_null();
 int is_readable(const char *name);
 int is_directory(const char *name);
 int file_exists(const char *name);
+bool get_open_file_xbits (FILE *f, bool *is_executable);
 const char *get_user_name();
 int user_is_group_member(gid_t gid);
-FILE *fcreate(mystring name, int mode);
+FILE *fcreate(const std::string& name, int mode);
 FILE *fopen_as_real_user(const char *name, const char *mode);
-bool set_file_mode(const mystring &gname, bool writable, bool executable);
-bool set_gfile_writable(const mystring &gname, bool writable, bool executable);
+bool set_file_mode(const string &gname, bool writable, bool executable);
+bool set_gfile_writable(const string& gname, bool writable, bool executable);
 bool unlink_gfile_if_present(const char *gfile_name);
 bool unlink_file_as_real_user(const char *gfile_name);
-void split_filename(const mystring &fullname,
-		    mystring& dirname,
-		    mystring& basename);
+void split_filename(const string& fullname,
+		    string& dirname,
+		    string& basename);
 
 
 #ifdef CONFIG_SYNC_BEFORE_REOPEN
