@@ -2,21 +2,21 @@
  * sf-delta.cc: Part of GNU CSSC.
  *
  *
- *    Copyright (C) 1997,1998,1999,2001,
- *                  2002,2007,2008 Free Software Foundation, Inc.
+ *  Copyright (C) 1997, 1998, 1999, 2001, 2002, 2007, 2008, 2009, 2010,
+ *  2011, 2014, 2019 Free Software Foundation, Inc.
  *
- *    This program is free software: you can redistribute it and/or modify
- *    it under the terms of the GNU General Public License as published by
- *    the Free Software Foundation, either version 3 of the License, or
- *    (at your option) any later version.
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- *    This program is distributed in the hope that it will be useful,
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *    You should have received a copy of the GNU General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  * CSSC was originally based on MySC, by Ross Ridge, which was
  * placed in the Public Domain.
@@ -25,7 +25,11 @@
  * Members of sccs_file for adding a delta to the SCCS file.
  *
  */
+#include <config.h>
+#include <string>
+
 #include <errno.h>
+#include <unistd.h>
 
 #include "cssc.h"
 #include "sccsfile.h"
@@ -38,14 +42,10 @@
 #include "delta-iterator.h"
 #include "bodyio.h"
 #include "filediff.h"
-#include "myset.h"
 #include "file.h"
 
 #undef JAY_DEBUG
 
-#include <unistd.h>
-
-
 
 class diff_state
 {
@@ -378,12 +378,12 @@ diff_state::process(FILE *out, seq_no seq)
 
 class FileDeleter
 {
-  mystring name;
+  std::string name;
   bool as_real_user;
   bool armed;
 
 public:
-  FileDeleter(const mystring& s, bool realuser)
+  FileDeleter(const std::string& s, bool realuser)
     : name(s), as_real_user(realuser), armed(true) { }
 
   ~FileDeleter()
@@ -422,11 +422,11 @@ static void line_too_long(long int max_len, size_t actual_len)
    performed before the object is destroyed. */
 
 bool
-sccs_file::add_delta(mystring gname,
+sccs_file::add_delta(const std::string& gname,
 		     sccs_pfile& pfile,
 		     sccs_pfile::iterator it,
-                     mylist<mystring> new_mrs,
-		     mylist<mystring> new_comments,
+                     const std::vector<std::string>& new_mrs,
+		     const std::vector<std::string>& new_comments,
                      bool display_diff_output)
 {
   const char *pline;
@@ -445,12 +445,12 @@ sccs_file::add_delta(mystring gname,
    * the name of this encoded file to diff, instead of the
    * name of the binary file itself.
    */
-  mystring file_to_diff;
+  std::string file_to_diff;
   bool bFileIsInWorkingDir;
 
   if (flags.encoded)
     {
-      mystring uname(name.sub_file('u'));
+      std::string uname(name.sub_file('u'));
       if (0 != encode_file(gname.c_str(), uname.c_str()))
         {
           return false;
@@ -482,7 +482,7 @@ sccs_file::add_delta(mystring gname,
 
 
   seq_state sstate(highest_delta_seqno());
-  const mystring sid_name = it->got.as_string();
+  const std::string sid_name = it->got.as_string();
   const delta *got_delta = find_delta(it->got);
   if (got_delta == NULL)
     {
@@ -503,7 +503,7 @@ sccs_file::add_delta(mystring gname,
   }
 
   /* The d-file is created in the SCCS directory (XXX: correct?) */
-  mystring dname(name.sub_file('d'));
+  std::string dname(name.sub_file('d'));
 
   /* We used to use fcreate here but as shown by the tests in
    * tests/delta/errorcase.sh, the prior existence of the
@@ -519,14 +519,12 @@ sccs_file::add_delta(mystring gname,
    * ID.  I believe that using the flag O_EXCL as fcreate() does resolves
    * that problem.
    */
-  FILE *get_out = fcreate(dname,
-			  CREATE_EXCLUSIVE |
-			  (flags.executable ? CREATE_EXECUTABLE : 0));
+  const int xmode = gfile_should_be_executable() ? CREATE_EXECUTABLE : 0;
+  FILE *get_out = fcreate(dname, CREATE_EXCLUSIVE | xmode);
   if (NULL == get_out)
     {
       remove(dname.c_str());
-      get_out = fcreate(dname, CREATE_EXCLUSIVE |
-			(flags.executable ? CREATE_EXECUTABLE : 0) );
+      get_out = fcreate(dname, CREATE_EXCLUSIVE | xmode);
     }
 
   if (NULL == get_out)
@@ -570,18 +568,18 @@ sccs_file::add_delta(mystring gname,
 
   // The new delta header includes info about what deltas
   // are included, excluded, ignored.   Compute that now.
-  myset<seq_no> included, excluded;
+  std::set<seq_no> included, excluded;
   for (seq_no iseq = 1; iseq < highest_delta_seqno(); iseq++)
     {
     if (sstate.is_explicitly_tagged(iseq))
       {
       if (sstate.is_included(iseq))
         {
-        included.add(iseq);
+	  included.insert(iseq);
         }
       else if (sstate.is_excluded(iseq))
         {
-          excluded.add(iseq);
+          excluded.insert(iseq);
         }
       }
     }
@@ -594,8 +592,8 @@ sccs_file::add_delta(mystring gname,
       // belonging to the new delta.
 
       // use our own comment.
-      mylist<mystring> auto_comment;
-      auto_comment.add(mystring("AUTO NULL DELTA"));
+      std::vector<std::string> auto_comment;
+      auto_comment.push_back(std::string("AUTO NULL DELTA"));
 
       release last_auto_rel = release(it->delta);
       // --last_auto_rel;
@@ -652,7 +650,7 @@ sccs_file::add_delta(mystring gname,
         {
           if (it->include.member(iter->id()))
             {
-              included.add(iter->seq());
+              included.insert(iter->seq());
             }
         }
     }
@@ -663,7 +661,7 @@ sccs_file::add_delta(mystring gname,
         {
           if (it->exclude.member(iter->id()))
             {
-              excluded.add(iter->seq());
+              excluded.insert(iter->seq());
             }
         }
     }
@@ -672,8 +670,7 @@ sccs_file::add_delta(mystring gname,
   // Construct the delta information for the new delta.
   delta new_delta('D', it->delta, sccs_date::now(),
                   get_user_name(), new_seq, predecessor_seq,
-                  included.list(), excluded.list(),
-		  new_mrs, new_comments);
+                  included, excluded, new_mrs, new_comments);
 
   // We don't know how many lines will be added/changed yet.
   // end_update() fixes that.
@@ -752,7 +749,7 @@ sccs_file::add_delta(mystring gname,
 #endif
 
 
-          // We just read a body line and prev delta is in in insert
+          // We just read a body line and prev delta is in insert
           // mode.  We need to decide if this line must also go into
           // this version.  If not, we need to emit delete commands.
           // On the other hand, we may need to insert data before it.
