@@ -15,11 +15,11 @@ export get
 # diff file1 and file2 and fail the test if they
 # are different.
 invariant () {
-if diff $2 $3
+if diff -u $2 $3
 then 
     echo passed
 else 
-    fail "$@"
+    fail "$1: $2 and $3 are not the same"
 fi ;
 }
 
@@ -44,20 +44,22 @@ unset  LANGUAGE LC_ALL LC_CTYPE LC_COLLATE LANG
 # counterexample for Debian GNU/Linux: LANG=de_DE.ISO-8859-1
 # export LANGUAGE LC_ALL LC_CTYPE LC_COLLATE LANG
 
+header="
+------- ${g} -------
+"
+
 
 echo_nonl "D1..."
 remove  $g
-${sccsdiff} -r1.1 -r1.2 $s 2>errs | 
-    sed '/lines/d' | 
-    sed '/1\./d'   > diff.out
+${sccsdiff} -r1.1 -r1.2 $s 2>errs >diff.out
 
-cat > diff.test <<EOF
-1a2
+cat > D1.diff.expected <<EOF
+${header}1a2
 > two
 EOF
 
 # Expect success
-invariant D1 diff.out diff.test
+invariant D1 diff.out D1.diff.expected
 remove errs
 
 #
@@ -65,18 +67,17 @@ remove errs
 #
 echo_nonl "D2..."
 remove diff.out
-${sccsdiff} -p -r1.1 -r1.2 $s 2>errs | 
-    sed '/lines/d' | 
-    sed '/1\./d'   | 
-    sed '/Page/d'  > diff.out
+
+${sccsdiff} -p -r1.1 -r1.2 $s 2>errs >diff.out
 
 
-remove  diff.test1
-pr diff.test | sed '/Page/d' > diff.test1
+remove diff.test1
+pr_header="s.foo: 1.1 vs. 1.2"
+cat D1.diff.expected | sed -e '1,2 d' | pr -h "${pr_header}" > D2.diff.expected
 
 # Expect success
-invariant D2 diff.out diff.test1
-remove  diff.test1 errs
+invariant D2 diff.out D2.diff.expected
+remove  diff.out D1.diff.expected D2.diff.expected errs
 
 
 #
